@@ -5,10 +5,12 @@ job related helpers
 import os
 import time
 import json
+import traceback
 
 import runpod.serverless.modules.logging as log
 from .worker_state import JOB_GET_URL, get_done_url
 from .retry import retry
+from .rp_tips import check_return_size
 
 
 async def get_job(session):
@@ -48,13 +50,20 @@ def run_job(handler, job):
             run_result = {"output": job_output}
         elif "error" in job_output:
             run_result = {"error": str(job_output['error'])}
+        elif "refresh_worker" in job_output:
+            job_output.pop("refresh_worker")
+            run_result = {
+                "stopPod": True,
+                "output": job_output
+            }
         else:
             run_result = {"output": job_output}
 
+        check_return_size(run_result)  # Checks the size of the return body.
     except Exception as err:    # pylint: disable=broad-except
         log.error(f"Error while running job {job['id']}: {err}")
 
-        run_result = {"error": str(err)}
+        run_result = {"error": f"handler: {str(err)} \ntraceback: {traceback.format_exc()}"}
 
     finally:
         log.info(f"Finished working on {job['id']} at {time.time()} UTC")
